PyTimings
=========

[![image](https://img.shields.io/pypi/v/pytimings.svg)](https://pypi.python.org/pypi/pytimings)

[![image](https://github.com/WWU-AMM/pytimings/workflows/pytest/badge.svg)](https://github.com/WWU-AMM/pytimings/actions)

[![Documentation Status](https://readthedocs.org/projects/pytimings/badge/?version=latest)](https://pytimings.readthedocs.io/en/latest/?badge=latest)


MPI Aware section timings

-   Free software: BSD license
-   Documentation: <https://pytimings.readthedocs.io>.
-   [![Live examples](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/WWU-AMM/pytimings/HEAD?filepath=docs%2Fexamples%2F)


Features
--------

-   TODO

Credits
-------

This package was created with
[Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
project template.
